==> 0.15.0.tar.gz: bentobox/src/main/java/world/bentobox/bentobox/listeners/flags/EntityInteractListener.java <==
package world.bentobox.bentobox.listeners.flags;

import org.bukkit.Material;
import org.bukkit.entity.Animals;
import org.bukkit.entity.ArmorStand;
import org.bukkit.entity.EntityType;
import org.bukkit.entity.Vehicle;
import org.bukkit.event.EventHandler;
import org.bukkit.event.EventPriority;
import org.bukkit.event.player.PlayerInteractAtEntityEvent;
import org.bukkit.event.player.PlayerInteractEntityEvent;

import world.bentobox.bentobox.api.flags.FlagListener;
import world.bentobox.bentobox.lists.Flags;

/**
 * Handles interaction with entities like armor stands
 * Note - armor stand protection from breaking or placing is done elsewhere.
 * @author tastybento
 *
 */
public class EntityInteractListener extends FlagListener {

    @EventHandler(priority = EventPriority.LOW, ignoreCancelled=true)
    public void onPlayerInteract(final PlayerInteractAtEntityEvent e) {
        if (e.getRightClicked() instanceof ArmorStand) {
            checkIsland(e, e.getRightClicked().getLocation(), Flags.ARMOR_STAND);
        }
    }

    @EventHandler(priority = EventPriority.LOW, ignoreCancelled = true)
    public void onPlayerHitEntity(PlayerInteractEntityEvent e) {
        // Animal riding
        if (e.getRightClicked() instanceof Vehicle && e.getRightClicked() instanceof Animals) {
            checkIsland(e, e.getRightClicked().getLocation(), Flags.RIDING);
        }
        // Villager trading
        if (e.getRightClicked().getType().equals(EntityType.VILLAGER)) {
            checkIsland(e, e.getRightClicked().getLocation(), Flags.TRADING);
        }
        // Name tags
        if (e.getPlayer().getInventory().getItemInMainHand().getType().equals(Material.NAME_TAG)) {
            checkIsland(e, e.getRightClicked().getLocation(), Flags.PLACE_BLOCKS);
        }
    }
}

==> 0.18.0.tar.gz: bentobox/src/main/java/world/bentobox/bentobox/listeners/flags/EntityInteractListener.java <==
package world.bentobox.bentobox.listeners.flags;

import org.bukkit.Material;
import org.bukkit.entity.Animals;
import org.bukkit.entity.ArmorStand;
import org.bukkit.entity.EntityType;
import org.bukkit.entity.Vehicle;
import org.bukkit.event.EventHandler;
import org.bukkit.event.EventPriority;
import org.bukkit.event.player.PlayerInteractAtEntityEvent;
import org.bukkit.event.player.PlayerInteractEntityEvent;

import world.bentobox.bentobox.api.flags.FlagListener;
import world.bentobox.bentobox.lists.Flags;

/**
 * Handles interaction with entities like armor stands
 * Note - armor stand protection from breaking or placing is done elsewhere.
 * @author tastybento
 *
 */
public class EntityInteractListener extends FlagListener {

    @EventHandler(priority = EventPriority.LOW, ignoreCancelled=true)
    public void onPlayerInteract(final PlayerInteractAtEntityEvent e) {
        if (e.getRightClicked() instanceof ArmorStand) {
            checkIsland(e, e.getRightClicked().getLocation(), Flags.ARMOR_STAND);
        }
    }

    @EventHandler(priority = EventPriority.LOW, ignoreCancelled = true)
    public void onPlayerHitEntity(PlayerInteractEntityEvent e) {
        // Animal riding
        if (e.getRightClicked() instanceof Vehicle && e.getRightClicked() instanceof Animals) {
            checkIsland(e, e.getRightClicked().getLocation(), Flags.RIDING);
        }
        // Villager trading
        if (e.getRightClicked().getType().equals(EntityType.VILLAGER)) {
            checkIsland(e, e.getRightClicked().getLocation(), Flags.TRADING);
        }
        // Name tags
        if (e.getPlayer().getInventory().getItemInMainHand().getType().equals(Material.NAME_TAG)) {
            checkIsland(e, e.getRightClicked().getLocation(), Flags.NAME_TAG);
        }
    }
}
